Each covered package ships a skill (`inst/skills/<package>/SKILL.md`). The ecosystem is also covered by a single combined agent, `nlmixr2verse` (see [list_agents()]), which is not itself a package and is therefore not listed here.
Each covered package ships a skill (`inst/skills/<package>/SKILL.md`). The ecosystem is also covered by a single combined agent, `nlmixr2verse` (see [list_agents()]), which is not itself a package and is therefore not listed here.